@@ -43,16 +43,16 @@ class PriceDbApplication:
 
         sec_repo = self.get_security_repo()
         security = sec_repo.get(price.security_id)
-        price.security = security
+        #price.security = security
         # This inserts the price record!
 
         if existing:
             # Update existing price.
             new_value = Decimal(price.value) / Decimal(price.denom)
-            self.logger.info(f"Exists: {price}")
+            self.logger.info(f"Exists: {security} {price}")
             if price.currency != existing.currency:
                 raise ValueError(
-                    f"The currency is different for price {price}!")
+                    f"The currency is different for price {security} {price}!")
             if existing.value != price.value:
                 existing.value = price.value
                 self.logger.info(f"Updating to {new_value}.")
@@ -61,7 +61,7 @@ class PriceDbApplication:
         else:
             # Insert new price
             self.session.add(price)
-            self.logger.info(f"Added {price}")
+            self.logger.info(f"Added {security} {price}")
 
     def download_prices(self, **kwargs):
         '''
@@ -311,13 +311,11 @@ class PriceDbApplication:
 
         # get all symbols that have prices
         repo = PriceRepository()
-        securities = repo.query.distinct(dal.Price.security_id).all()
-        # self.logger.debug(items)
+        prices = repo.query.distinct(dal.Price.security_id).all()
         count = 0
 
-        for item in securities:
-            #symbol = SecuritySymbol(item.namespace, item.symbol)
-            deleted = self.prune(item.id)
+        for item in prices:
+            deleted = self.prune(item.security_id)
             if deleted:
                 count += 1
 
@@ -330,7 +328,6 @@ class PriceDbApplication:
         '''
         from .repositories import PriceRepository
 
-        #assert isinstance(symbol, SecuritySymbol)
         assert isinstance(security_id, int)
 
         self.logger.debug(f"pruning prices for {security_id}")
@@ -343,7 +340,6 @@ class PriceDbApplication:
             .order_by(dal.Price.time.desc())
         )
         all_prices = query.all()
-        # self.logger.debug(f"fetched {all_prices}")
 
         deleted = False
         first = True
