@@ -1,10 +1,9 @@
 """
 Data layer
 """
-from sqlalchemy import create_engine
+from sqlalchemy import create_engine, Column, Integer, String, ForeignKey
 from sqlalchemy.ext.declarative import declarative_base
-from sqlalchemy.orm import sessionmaker
-from sqlalchemy import Column, Integer, String
+from sqlalchemy.orm import relationship, sessionmaker
 
 Base = declarative_base()
 
@@ -14,10 +13,9 @@ class Price(Base):
     __tablename__ = 'price'
 
     id = Column(Integer, primary_key=True)
-    security_id = Column(Integer)
-    # TODO: remove these columns
-    namespace = Column(String)
-    symbol = Column(String)
+    security_id = Column(Integer, ForeignKey('security.id'))
+    # namespace = Column(String)
+    # symbol = Column(String)
 
     date = Column(String)
     time = Column(String)
@@ -25,18 +23,23 @@ class Price(Base):
     denom = Column(Integer)
     currency = Column(String)
 
+    # https://docs.sqlalchemy.org/en/13/orm/basic_relationships.html#one-to-many
+    security = relationship('Security', back_populates='prices')
+
     def __repr__(self):
         actual_value = 0
         if self.denom:
             actual_value = self.value / self.denom
         actual_value_str = f"{actual_value:.2f}"
 
-        # symbol = f"{self.namespace}:{self.symbol}" if self.namespace else self.symbol
-        # if symbol is None:
-        #     symbol = ""
-        # formatted_symbol = f"{symbol:<13}"
+        formatted_symbol = ""
+        if self.security:
+            symbol = f"{self.security.namespace}:{self.security.symbol}" if self.security.namespace else self.security.symbol
+            if symbol is None:
+                symbol = ""
+            formatted_symbol = f"{symbol:<13}"
 
-        return f"<Price ({self.security_id},{self.date} {self.time},{actual_value_str:>6} {self.currency})>"
+        return f"<Price ({formatted_symbol},{self.date} {self.time},{actual_value_str:>6} {self.currency})>"
 
 
 class Security(Base):
@@ -52,6 +55,8 @@ class Security(Base):
     currency = Column(String)
     ledger_symbol = Column(String)
 
+    prices = relationship('Price')
+
     def __repr__(self):
         return f"<Security ({self.id}, {self.namespace}:{self.symbol})>"
 
